termui_audio library

Classes

AudioBuffer
Represents a loaded sound source.
AudioBus
Represents a mixing bus.
AudioVoice
A handle for a playing sound.
SpriteSegment
Represents a timestamp offset and duration segment within an audio sprite sheet.
TermuiAudio
The top-level multiplatform entry point for the termui audio system.
TermuiAudioEngine
The core engine service abstracting the audio backend.

Enums

AttenuationModel
The 3D audio distance attenuation model.
FilterType
Supported DSP filter types matching native C++ SoLoud indices.
WaveForm
The types of waveforms supported by the synthesizer.

Typedefs

LoadProgressCallback = void Function(double progress)
A callback used to report progress when loading an audio file.